#
# vim:set syntax=python:
#import os

import sys
import time
from types import *


#   ---------=========== CLASS: config      ===========---------
#
# Config class -- Defines what everything is doing
#
#
class config:
	def __init__(self):                  
		self.iterations = 0                # Number of times the prog have iterated through its main cycle

		self.startDate  = time.asctime( time.localtime(time.time()) ) # Start time of prog

	def setTask(self,request=[ ]):       # Defines task -> Control property -> defines what people do
		self.task = request


#   ---------=========== CLASS: log         ===========---------
#
# Log class -- Does the logging work
#
#   Instanciate log obj. by passing logfile name, and/or log lvl 
#   log lvl is 0-7, 0 is ALERT, 7 is Debug (syslog lvls)
#
#
class log:                          
	def __init__(self, cfg, file, level = 5):
		self.filename  = file              
		self.level     = level             
		self.cfg       = cfg               # So I can find config later

		self.lf = open(self.filename,'a',-1)
# 		self.lf.write("Process started\n") 
		self.write("---=== Process started " + cfg.startDate + " ===---\n") 

	def close(self):
		self.lf.flush()
		self.lf.close()

	def write(self,msg):
# 		self.lf.write(msg.rstrip() + '\n') 
		print >>self.lf, msg.rstrip()

	# log classes. (syntax e.g. log.debug("blip blop flip flop))

	def debug(self,msg):
		if self.level >= 7: self.write(msg)

	def info(self,msg):
		if self.level >= 6: self.write(msg)

	def notice(self,msg):
		if self.level >= 5: self.write(msg)

	def warn(self,msg):
		if self.level >= 4: self.write(msg)

	def error(self,msg):
		if self.level >= 3: self.write(msg)

	def critical(self,msg):
		if self.level >= 2: self.write(msg)

	def alert(self,msg):
		if self.level >= 1: self.write(msg)

	def emergency(self,msg):
		if self.level >= 0: self.write(msg)


#   ---------=========== CLASS: introscope  ===========---------
#
# Introscope class -- provides methods for introscope stuff
#
#  # Instanciate instroscope obj, outStream = (stdout|socket), outFmt = (xml|simple)
#    Using socket requires the cfg object to hold the necessary
#
class introscope:

	def __init__(self, cfg, outStream = 'stdout', outFmt = 'xml'): 
		self.outFmt    = outFmt
		self.outStream = outStream
		self.cfg       = cfg
		self.metricPrefix = ""
		
#
# PREFIX
#
# Possible syntaxs are:
#   obj.prefix( 'WASMonitor' )
#   obj.prefix( 'WASMonitor|stuff|1|2' )
#   obj.prefix([ "WASMonitor", "fred", "ginger", "apple" ])
#
#
	def prefix(self, value):
		nameString = '' 

		if type(value) == ListType:                                   # LIST: is the val of value a list ?
			if len(value) > 1:                                          # LIST: is the list in value more than 1 item
				first = 1
				for index in range(len(value) - 1):                       # LIST: print a item except last one, prefix with '|' except the first one
					if first == 1:  
						first = 0 
						nameString += value[index] 
					else: 
						nameString += '|' + value[index]                      
				nameString += '|' + value[-1]                             # LIST: print last item with a ':' prefix
			else: 
				nameString += value[-1]                                   # LIST: print the 1 list item as if it was a preprepared string
		else: 
			nameString += value
			
		self.metricPrefix = nameString + "|"
		print "Introscope Metrics have a new common prefix: %s" % self.metricPrefix


#
#  METRIC
#
# Possible syntaxs are:
# 	obj.metric("IntCounter", ['one', 'two', 'three'], "valuealicious")  
# 	obj.metric("IntCounter", ['one|two:three'],       "valuealicious")  
# 	obj.metric("IntCounter", 'one|two:three',         "valuealicious") 
#
#
	def metric(self, metricType, name, value):

		# -------- Metric Types -------
                # metricTypes will be used in the furture, where metricType can be numeric
                
                metricTypes = [ 'IntAverage',
                                'IntCounter',
                                'LongCounter',
                                'PerIntervalCounter',
                                'StringEvent' ]
		
		nameString = self.metricPrefix

		if type(name) == ListType:                                   # LIST: is the val of name a list ?
			if len(name) > 1:                                          # LIST: is the list in name more than 1 item
				first = 1
				for index in range(len(name) - 1):                       # LIST: print a item except last one, prefix with '|' except the first one
					if first == 1:  
						first = 0 
						nameString += name[index] 
					else: 
						nameString += '|' + name[index]                      
				nameString += ':' + name[-1]                             # LIST: print last item with a ':' prefix
			else: 
				nameString += name[-1]                                   # LIST: print the 1 list item as if it was a preprepared string
		else: 
			nameString += name

		print '<metric type="' + metricType + '" name="' + nameString + '" value="' + value + '" />'
